@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 # shortcuts
 #  os and distros
@@ -1838,7 +1838,10 @@ sub mapping {
       [os_freebsd,
        [package => 'freeglut']],
       [like_debian,
-       [package => ['freeglut3-dev', 'libxmu-dev', 'libxi-dev']]]],
+       [package => ['freeglut3-dev', 'libxmu-dev', 'libxi-dev']]],
+      [like_fedora,
+       [package => ['freeglut-devel', 'libXmu-devel']]],
+     ],
 
      [cpanmod => 'OpenGL::FTGL',
       [like_debian,
@@ -1945,6 +1948,25 @@ sub mapping {
       [like_debian,
        [package => 'ragel']]],
 
+     [cpanmod => 're::engine::Hyperscan',
+      # not available on freebsd & CentOS7
+      [like_debian,
+       [linuxdistrocodename => [qw(squeeze wheezy jessie xenial)],
+	[package => []]], # not available before stretch
+       [package => 'libhyperscan-dev']],
+     ],
+
+     [cpanmod => 're::engine::PCRE2',
+      [os_freebsd,
+       [package => 'pcre2']],
+      [like_debian,
+       [linuxdistrocodename => [qw(squeeze wheezy jessie)],
+	[package => []]], # not available before stretch; available on Ubuntu/xenial
+       [package => 'libpcre2-dev']],
+      [like_fedora,
+       [package => 'pcre2-devel']],
+     ],
+
      [cpanmod => 'RPC::Xmlrpc_c::Client',
       [os_freebsd,
        [package => 'xmlrpc-c']],
@@ -2372,6 +2394,15 @@ sub mapping {
       [like_debian,
        [package => ['xsltproc', 'xcb-proto', 'libxcb-util0-dev', 'libxcb-xinerama0-dev', 'libxcb-icccm4-dev']]]],
 
+     [cpanmod => 'X11::Xlib',
+      [os_freebsd,
+       [package => 'libXtst']],
+      [like_debian,
+       [package => 'libxtst-dev']],
+      [like_fedora,
+       [package => 'libXtst-devel']],
+     ],
+
      [cpanmod => 'ZMQ::FFI',
       [os_freebsd,
        [package => 'libzmq4']], # seems to hang with nonthreaded perls on freebsd, wait-and-kill rule exists
